==> kas_2.5.orig.tar.xz: kas-2.5/CHANGELOG.md <==
2.5
- kas: Apply patches before doing an environment setup
- kas: repos: strip dot from layer name
- kas: Introduce KAS_BUILD_DIR environment variable
- kas: add GIT_CREDENTIAL_HELPER environment variable
- kas-container: add `--git-credential-store` options
- kas-container: mount /repo as read-write for shell command
- kas-container: add an argument to get version information
- kas-container: Add support for checkout and for-all-repos
- kas-container: add support to set a custom container images location
- kas-container: Fix mounting of custom KAS_REPO_REF_DIR
- kas-container: Add skopeo and umoci to ISAR image
- kas-container: add sudo to standard kas image

2.4
- kas: Silence "Exception ignored when trying to write to the signal wakeup fd"
- kas: drop bitbakes "-k" from the default args
- kas: fix repos path if no url, but path given
- kas: Set upper version limit for dependencies
- kas-container: Add support for rootless podman with userns keep-id
- kas-container: Add support for multi-word --command arguments
- kas-container: make sure that we pass shellcheck
- kas-container/kas*: Add support for multi-arch containers
- kas-container/kas: Pull all Python dependencies from Debian
- kas-container/kas-isar: Drop grub package

2.3.3
- Fix binfmt setup in kas-isar container image

2.3.2
- Fix release script fix /wrt kas-container image version updates

2.3.1
- Fix release scripting

2.3
- kas: add "checkout" and for-all-repos subcommands
- kas: add python 3.9 compatibility
- kas: improve documentation
- config: add build_system property to pre-select OE/Yocto or Isar
- kas-container: rename from kas-docker
- kas-container: add support for build_system property (making --isar optional)
- kas-container: adjust environment variables interface
- kas-container: switch to github container repository
- kas-container: add support for Debian bullseye cross building
- kas-container: add zstd package

2.2
- kas: allow extra bitbake arguments to be passed
- kas: add --force-checkout and --update arguments to ease CI usage
- kas: allow for layer-free repositories
- kas: fix cloning of repos without default branch
- kas: enable standard-conforming .yaml file extensions
- kas-docker: enhance with podman support
- kas-docker: switch to /bin/bash as SHELL per default
- config: Allow a default refspec to be specified
- config: Allow a default repo to be specified for patches

2.1.1
- repos: Silence pycodestyle error (that broke docker image generation)

2.1
- Add support for S3 fetcher to docker image
- Lift Python minimal requirements to 3.5
- Fix reporting of of repo patch IDs
- config: use 'qemux86-64' instead of 'qemu' as default for KAS_MACHINE
- Ensure SSH key ends with newline
- kas-docker: Make it harder to run as root
- kas-docker: Make loop device passing optional
- kas-docker: Various fixes

2.0
- Add support for Yocto 3.0 / latest Isar
- Move docker image to Debian buster
- Add git-lfs support to docker image
- Add Yocto testimage dependencies to docker image

1.1
- Restore mercurial support
- Add -c and --cmd as aliases for --task
- Fix repo patching when using a branch name as refspec
- Update repo remote URL on kas file changes
- kas-docker: fix SHELL forwarding
- kas-docker: use released image, rather than "latest"
- kas-docker: allow to define custom image version
- kasproject/kas: enable devshell and menuconfig targets
- kasproject/kas image: add gnupg and quilt
- kasproject/kas-isar image: fix /var/tmp handling

1.0
- isar: Take qemu-user-static from buster and adjust binfmt setup

0.20.1
- kas-docker: Restore KAS_PREMIRRORS support

0.20.0
- kas-docker: enable passing SSH configs
- kas-docker: add --no-proxy-from-env option
- kas-docker: Pass in NO_PROXY
- Add KAS_PREMIRRORS support
- Remove SSH_AGENT_PID forwarding

0.19.0
- Recursive include handler refactoring and cleanups
- A lot of code cleanups, refactoring and bug fixings
- Isar docker support improvements

0.18.0
- Add patch support for repos
- Use git diff-index to check if repo is dirty
- docker: add debootstrap and qemu-user-static

0.17.0
- Add iproute and zx-utils to the docker image
- Fix relative path for repos
- Write MACHINE and DISTRO as weak defaults

0.16.0
- Support Mercurial repos
- Support Gentoo distro

0.15.0
- Environment variable passthrough
- Support major distro variants
- Add initial support for multiconfig

0.14.0
- Multi-target support
- Avoid downloading same repo twice

0.13.0
- Increase config file version

0.12.0
- Remove dynamic configuration support (Python config files)
- Shell command prepares complete bitbake configuration
- Add to define task in config and environment
- Improved error handling and reporting

0.11.0
- Allow in-tree repos not to be in a git repo
- Pass through git proxy related environment variables
- Write deterministic local.conf and bblayers.con
- Make configuration file versioning independent of project version
- Cleanups for uploading project to PyPI
- Print proper error message for config file format exception

0.10.0
- Docker image creation (Debian Stretch), pushed on kasproject/kas
- Restructure documentation add support for Sphinx export it to readthedocs
- Add support for include feature for Yaml files
- Add support for Isar build system
- Handling of SIGTERM/TERM improved
- Parallel download of git sources
- Allow environment to overwrite proxy, target, machine and distro
- Add unit testing for include/merge config file handling
- Rename sublayers back to layers
- pylint & pep8 cleanups
- Allow to define workdir via KAS_WORK_DIR
- Shell honors SHELL and TERM environment variable

0.9.0
- initial public release

==> kas_2.6.3.orig.tar.xz: kas-2.6.3/CHANGELOG.md <==
2.6.3
- kas: Do not overwrite existing .ssh/config
- kas: Properly describe package build
- kas-container: create KAS_WORK_DIR if it not exists
- kas-container: validate KAS_REPO_REF_DIR correctness
- docs: Fix generation
- docs: Extended "layers" section in the user guide.

2.6.2
- kas-container: Restore oe-git-proxy location (/usr/bin)
- kas-container: Drop world-write permission from /kas folder

2.6.1
- kas: fix installation via pip

2.6
- kas: Add kconfiglib-based menu plugin
- kas: Enable kas to checkout repositories using git credentials
- kas: Enable gerrit/gitlab/github refspecs
- kas: Write more bblayers.conf boilerplate settings
- kas: Add environment variable SSH_PRIVATE_KEY_FILE
- kas: Add support for relative KAS_WORK/BUILD/REPO_REF_DIR paths
- kas: Move config json schema to standalone json file
- kas: Avoid duplicate cloning of repos in command line includes
- kas: for_all_repos: Exit on command failure
- kas: for_all_repos: Fix KAS_REPO_URL or unversioned repos
- kas: Declare proxy_config obsolete
- kas-container: install lz4
- kas-container: install g++-multilib
- kas-container: install newer git-lfs
- kas-container: Enter with /repo as current dir
- kas-container: Carry oe-git-proxy locally and relocate to /usr/local/bin

2.5
- kas: Apply patches before doing an environment setup
- kas: repos: strip dot from layer name
- kas: Introduce KAS_BUILD_DIR environment variable
- kas: add GIT_CREDENTIAL_HELPER environment variable
- kas-container: add `--git-credential-store` options
- kas-container: mount /repo as read-write for shell command
- kas-container: add an argument to get version information
- kas-container: Add support for checkout and for-all-repos
- kas-container: add support to set a custom container images location
- kas-container: Fix mounting of custom KAS_REPO_REF_DIR
- kas-container: Add skopeo and umoci to ISAR image
- kas-container: add sudo to standard kas image

2.4
- kas: Silence "Exception ignored when trying to write to the signal wakeup fd"
- kas: drop bitbakes "-k" from the default args
- kas: fix repos path if no url, but path given
- kas: Set upper version limit for dependencies
- kas-container: Add support for rootless podman with userns keep-id
- kas-container: Add support for multi-word --command arguments
- kas-container: make sure that we pass shellcheck
- kas-container/kas*: Add support for multi-arch containers
- kas-container/kas: Pull all Python dependencies from Debian
- kas-container/kas-isar: Drop grub package

2.3.3
- Fix binfmt setup in kas-isar container image

2.3.2
- Fix release script fix /wrt kas-container image version updates

2.3.1
- Fix release scripting

2.3
- kas: add "checkout" and for-all-repos subcommands
- kas: add python 3.9 compatibility
- kas: improve documentation
- config: add build_system property to pre-select OE/Yocto or Isar
- kas-container: rename from kas-docker
- kas-container: add support for build_system property (making --isar optional)
- kas-container: adjust environment variables interface
- kas-container: switch to github container repository
- kas-container: add support for Debian bullseye cross building
- kas-container: add zstd package

2.2
- kas: allow extra bitbake arguments to be passed
- kas: add --force-checkout and --update arguments to ease CI usage
- kas: allow for layer-free repositories
- kas: fix cloning of repos without default branch
- kas: enable standard-conforming .yaml file extensions
- kas-docker: enhance with podman support
- kas-docker: switch to /bin/bash as SHELL per default
- config: Allow a default refspec to be specified
- config: Allow a default repo to be specified for patches

2.1.1
- repos: Silence pycodestyle error (that broke docker image generation)

2.1
- Add support for S3 fetcher to docker image
- Lift Python minimal requirements to 3.5
- Fix reporting of of repo patch IDs
- config: use 'qemux86-64' instead of 'qemu' as default for KAS_MACHINE
- Ensure SSH key ends with newline
- kas-docker: Make it harder to run as root
- kas-docker: Make loop device passing optional
- kas-docker: Various fixes

2.0
- Add support for Yocto 3.0 / latest Isar
- Move docker image to Debian buster
- Add git-lfs support to docker image
- Add Yocto testimage dependencies to docker image

1.1
- Restore mercurial support
- Add -c and --cmd as aliases for --task
- Fix repo patching when using a branch name as refspec
- Update repo remote URL on kas file changes
- kas-docker: fix SHELL forwarding
- kas-docker: use released image, rather than "latest"
- kas-docker: allow to define custom image version
- kasproject/kas: enable devshell and menuconfig targets
- kasproject/kas image: add gnupg and quilt
- kasproject/kas-isar image: fix /var/tmp handling

1.0
- isar: Take qemu-user-static from buster and adjust binfmt setup

0.20.1
- kas-docker: Restore KAS_PREMIRRORS support

0.20.0
- kas-docker: enable passing SSH configs
- kas-docker: add --no-proxy-from-env option
- kas-docker: Pass in NO_PROXY
- Add KAS_PREMIRRORS support
- Remove SSH_AGENT_PID forwarding

0.19.0
- Recursive include handler refactoring and cleanups
- A lot of code cleanups, refactoring and bug fixings
- Isar docker support improvements

0.18.0
- Add patch support for repos
- Use git diff-index to check if repo is dirty
- docker: add debootstrap and qemu-user-static

0.17.0
- Add iproute and zx-utils to the docker image
- Fix relative path for repos
- Write MACHINE and DISTRO as weak defaults

0.16.0
- Support Mercurial repos
- Support Gentoo distro

0.15.0
- Environment variable passthrough
- Support major distro variants
- Add initial support for multiconfig

0.14.0
- Multi-target support
- Avoid downloading same repo twice

0.13.0
- Increase config file version

0.12.0
- Remove dynamic configuration support (Python config files)
- Shell command prepares complete bitbake configuration
- Add to define task in config and environment
- Improved error handling and reporting

0.11.0
- Allow in-tree repos not to be in a git repo
- Pass through git proxy related environment variables
- Write deterministic local.conf and bblayers.con
- Make configuration file versioning independent of project version
- Cleanups for uploading project to PyPI
- Print proper error message for config file format exception

0.10.0
- Docker image creation (Debian Stretch), pushed on kasproject/kas
- Restructure documentation add support for Sphinx export it to readthedocs
- Add support for include feature for Yaml files
- Add support for Isar build system
- Handling of SIGTERM/TERM improved
- Parallel download of git sources
- Allow environment to overwrite proxy, target, machine and distro
- Add unit testing for include/merge config file handling
- Rename sublayers back to layers
- pylint & pep8 cleanups
- Allow to define workdir via KAS_WORK_DIR
- Shell honors SHELL and TERM environment variable

0.9.0
- initial public release
